@@ -1,9 +1,8 @@
-_base_ = ['../../../../_base_/datasets/jhmdb.py']
-log_level = 'INFO'
+_base_ = [
+    '../../../../_base_/default_runtime.py',
+    '../../../../_base_/datasets/jhmdb.py'
+]
 load_from = 'https://download.openmmlab.com/mmpose/top_down/resnet/res50_mpii_256x256-418ffc88_20200812.pth'  # noqa: E501
-resume_from = None
-dist_params = dict(backend='nccl')
-workflow = [('train', 1)]
 checkpoint_config = dict(interval=1)
 evaluation = dict(interval=1, metric=['PCK', 'tPCK'], save_best='Mean PCK')
 
@@ -20,13 +19,6 @@ lr_config = dict(
     warmup_ratio=0.001,
     step=[8, 15])
 total_epochs = 20
-log_config = dict(
-    interval=50,
-    hooks=[
-        dict(type='TextLoggerHook'),
-        # dict(type='TensorboardLoggerHook')
-    ])
-
 channel_cfg = dict(
     num_output_channels=15,
     dataset_joints=15,
@@ -86,7 +78,7 @@ train_pipeline = [
         keys=['img', 'target', 'target_weight'],
         meta_keys=[
             'image_file', 'joints_3d', 'joints_3d_visible', 'center', 'scale',
-            'rotation', 'bbox', 'flip_pairs'
+            'rotation', 'bbox_score', 'flip_pairs'
         ]),
 ]
 
@@ -104,7 +96,8 @@ val_pipeline = [
             'img',
         ],
         meta_keys=[
-            'image_file', 'center', 'scale', 'rotation', 'bbox', 'flip_pairs'
+            'image_file', 'center', 'scale', 'rotation', 'bbox_score',
+            'flip_pairs'
         ]),
 ]
 
@@ -118,21 +111,21 @@ data = dict(
     test_dataloader=dict(samples_per_gpu=32),
     train=dict(
         type='TopDownJhmdbDataset',
-        ann_file=f'{data_root}/annotations/Sub3_train.json',
+        ann_file=f'{data_root}/annotations/Sub1_train.json',
         img_prefix=f'{data_root}/',
         data_cfg=data_cfg,
         pipeline=train_pipeline,
         dataset_info={{_base_.dataset_info}}),
     val=dict(
         type='TopDownJhmdbDataset',
-        ann_file=f'{data_root}/annotations/Sub3_test.json',
+        ann_file=f'{data_root}/annotations/Sub1_test.json',
         img_prefix=f'{data_root}/',
         data_cfg=data_cfg,
         pipeline=val_pipeline,
         dataset_info={{_base_.dataset_info}}),
     test=dict(
         type='TopDownJhmdbDataset',
-        ann_file=f'{data_root}/annotations/Sub3_test.json',
+        ann_file=f'{data_root}/annotations/Sub1_test.json',
         img_prefix=f'{data_root}/',
         data_cfg=data_cfg,
         pipeline=test_pipeline,
