@@ -1,9 +1,7 @@
-_base_ = ['../../../../_base_/datasets/coco_wholebody_face.py']
-log_level = 'INFO'
-load_from = None
-resume_from = None
-dist_params = dict(backend='nccl')
-workflow = [('train', 1)]
+_base_ = [
+    '../../../../_base_/default_runtime.py',
+    '../../../../_base_/datasets/coco_wholebody_face.py'
+]
 checkpoint_config = dict(interval=1)
 evaluation = dict(interval=1, metric=['NME'], key_indicator='NME')
 
