@@ -1,5 +1,6 @@
 # Copyright (c) OpenMMLab. All rights reserved.
 from .camera_base import CAMERAS
 from .single_camera import SimpleCamera
+from .single_camera_torch import SimpleCameraTorch
 
-__all__ = ['CAMERAS', 'SimpleCamera']
+__all__ = ['CAMERAS', 'SimpleCamera', 'SimpleCameraTorch']
