@@ -1,9 +1,10 @@
 # Copyright (c) OpenMMLab. All rights reserved.
 from .effects import apply_bugeye_effect, apply_sunglasses_effect
 from .image import (imshow_bboxes, imshow_keypoints, imshow_keypoints_3d,
-                    imshow_mesh_3d)
+                    imshow_mesh_3d, imshow_multiview_keypoints_3d)
 
 __all__ = [
     'imshow_keypoints', 'imshow_keypoints_3d', 'imshow_bboxes',
-    'apply_bugeye_effect', 'apply_sunglasses_effect', 'imshow_mesh_3d'
+    'apply_bugeye_effect', 'apply_sunglasses_effect', 'imshow_mesh_3d',
+    'imshow_multiview_keypoints_3d'
 ]
