@@ -140,70 +140,72 @@ def imshow_keypoints(img,
         # draw each point on image
         if pose_kpt_color is not None:
             assert len(pose_kpt_color) == len(kpts)
+
             for kid, kpt in enumerate(kpts):
                 x_coord, y_coord, kpt_score = int(kpt[0]), int(kpt[1]), kpt[2]
-                if kpt_score > kpt_score_thr:
-                    if show_keypoint_weight:
-                        img_copy = img.copy()
-                        r, g, b = pose_kpt_color[kid]
-                        cv2.circle(img_copy, (int(x_coord), int(y_coord)),
-                                   radius, (int(r), int(g), int(b)), -1)
-                        transparency = max(0, min(1, kpt_score))
-                        cv2.addWeighted(
-                            img_copy,
-                            transparency,
-                            img,
-                            1 - transparency,
-                            0,
-                            dst=img)
-                    else:
-                        r, g, b = pose_kpt_color[kid]
-                        cv2.circle(img, (int(x_coord), int(y_coord)), radius,
-                                   (int(r), int(g), int(b)), -1)
+
+                if kpt_score < kpt_score_thr or pose_kpt_color[kid] is None:
+                    # skip the point that should not be drawn
+                    continue
+
+                color = tuple(int(c) for c in pose_kpt_color[kid])
+                if show_keypoint_weight:
+                    img_copy = img.copy()
+                    cv2.circle(img_copy, (int(x_coord), int(y_coord)), radius,
+                               color, -1)
+                    transparency = max(0, min(1, kpt_score))
+                    cv2.addWeighted(
+                        img_copy,
+                        transparency,
+                        img,
+                        1 - transparency,
+                        0,
+                        dst=img)
+                else:
+                    cv2.circle(img, (int(x_coord), int(y_coord)), radius,
+                               color, -1)
 
         # draw links
         if skeleton is not None and pose_link_color is not None:
             assert len(pose_link_color) == len(skeleton)
+
             for sk_id, sk in enumerate(skeleton):
                 pos1 = (int(kpts[sk[0], 0]), int(kpts[sk[0], 1]))
                 pos2 = (int(kpts[sk[1], 0]), int(kpts[sk[1], 1]))
-                if (pos1[0] > 0 and pos1[0] < img_w and pos1[1] > 0
-                        and pos1[1] < img_h and pos2[0] > 0 and pos2[0] < img_w
-                        and pos2[1] > 0 and pos2[1] < img_h
-                        and kpts[sk[0], 2] > kpt_score_thr
-                        and kpts[sk[1], 2] > kpt_score_thr):
-                    r, g, b = pose_link_color[sk_id]
-                    if show_keypoint_weight:
-                        img_copy = img.copy()
-                        X = (pos1[0], pos2[0])
-                        Y = (pos1[1], pos2[1])
-                        mX = np.mean(X)
-                        mY = np.mean(Y)
-                        length = ((Y[0] - Y[1])**2 + (X[0] - X[1])**2)**0.5
-                        angle = math.degrees(
-                            math.atan2(Y[0] - Y[1], X[0] - X[1]))
-                        stickwidth = 2
-                        polygon = cv2.ellipse2Poly(
-                            (int(mX), int(mY)),
-                            (int(length / 2), int(stickwidth)), int(angle), 0,
-                            360, 1)
-                        cv2.fillConvexPoly(img_copy, polygon,
-                                           (int(r), int(g), int(b)))
-                        transparency = max(
-                            0, min(1, 0.5 * (kpts[sk[0], 2] + kpts[sk[1], 2])))
-                        cv2.addWeighted(
-                            img_copy,
-                            transparency,
-                            img,
-                            1 - transparency,
-                            0,
-                            dst=img)
-                    else:
-                        cv2.line(
-                            img,
-                            pos1,
-                            pos2, (int(r), int(g), int(b)),
-                            thickness=thickness)
+
+                if (pos1[0] <= 0 or pos1[0] >= img_w or pos1[1] <= 0
+                        or pos1[1] >= img_h or pos2[0] <= 0 or pos2[0] >= img_w
+                        or pos2[1] <= 0 or pos2[1] >= img_h
+                        or kpts[sk[0], 2] < kpt_score_thr
+                        or kpts[sk[1], 2] < kpt_score_thr
+                        or pose_link_color[sk_id] is None):
+                    # skip the link that should not be drawn
+                    continue
+                color = tuple(int(c) for c in pose_link_color[sk_id])
+                if show_keypoint_weight:
+                    img_copy = img.copy()
+                    X = (pos1[0], pos2[0])
+                    Y = (pos1[1], pos2[1])
+                    mX = np.mean(X)
+                    mY = np.mean(Y)
+                    length = ((Y[0] - Y[1])**2 + (X[0] - X[1])**2)**0.5
+                    angle = math.degrees(math.atan2(Y[0] - Y[1], X[0] - X[1]))
+                    stickwidth = 2
+                    polygon = cv2.ellipse2Poly(
+                        (int(mX), int(mY)), (int(length / 2), int(stickwidth)),
+                        int(angle), 0, 360, 1)
+                    cv2.fillConvexPoly(img_copy, polygon, color)
+                    transparency = max(
+                        0, min(1, 0.5 * (kpts[sk[0], 2] + kpts[sk[1], 2])))
+                    cv2.addWeighted(
+                        img_copy,
+                        transparency,
+                        img,
+                        1 - transparency,
+                        0,
+                        dst=img)
+                else:
+                    cv2.line(img, pos1, pos2, color, thickness=thickness)
 
     return img
 
@@ -446,3 +448,75 @@ def imshow_mesh_3d(img,
             valid_mask * color[:, :, :3] + (1 - valid_mask) * output_img)
 
     return output_img
+
+
+def imshow_multiview_keypoints_3d(
+    pose_result,
+    skeleton=None,
+    pose_kpt_color=None,
+    pose_link_color=None,
+    space_size=[8000, 8000, 2000],
+    space_center=[0, -500, 800],
+    kpt_score_thr=0.0,
+):
+    """Draw 3D keypoints and links in 3D coordinates.
+
+    Args:
+        pose_result (list[kpts]): The poses to draw. Each element kpts is
+            a set of K keypoints as an Kx4 numpy.ndarray, where each
+            keypoint is represented as x, y, z, score.
+        skeleton (list of [idx_i,idx_j]): Skeleton described by a list of
+            links, each is a pair of joint indices.
+        pose_kpt_color (np.ndarray[Nx3]`): Color of N keypoints. If None, do
+            not nddraw keypoints.
+        pose_link_color (np.array[Mx3]): Color of M links. If None, do not
+            draw links.
+        space_size: (list). Default: [8000, 8000, 2000].
+        space_center: (list). Default: [0, -500, 800].
+        kpt_score_thr (float): Minimum score of keypoints to be shown.
+            Default: 0.0.
+    """
+    fig = plt.figure()
+    ax = plt.axes(projection='3d')
+    ax.set_xlim3d(space_center[0] - space_size[0] * 0.5,
+                  space_center[0] + space_size[0] * 0.5)
+    ax.set_ylim3d(space_center[1] - space_size[1] * 0.5,
+                  space_center[1] + space_size[1] * 0.5)
+    ax.set_zlim3d(space_center[2] - space_size[2] * 0.5,
+                  space_center[2] + space_size[2] * 0.5)
+    pose_kpt_color = np.array(pose_kpt_color)
+    pose_kpt_color = pose_kpt_color[..., ::-1] / 255.
+
+    for kpts in pose_result:
+        # draw each point on image
+        xs, ys, zs, scores = kpts.T
+        valid = scores > kpt_score_thr
+        ax.scatter(
+            xs[valid],
+            ys[valid],
+            zs[valid],
+            marker='o',
+            color=pose_kpt_color[valid])
+
+        for link, link_color in zip(skeleton, pose_link_color):
+            link_indices = [_i for _i in link]
+            xs_3d = kpts[link_indices, 0]
+            ys_3d = kpts[link_indices, 1]
+            zs_3d = kpts[link_indices, 2]
+            kpt_score = kpts[link_indices, 3]
+            if kpt_score.min() > kpt_score_thr:
+                # matplotlib uses RGB color in [0, 1] value range
+                _color = np.array(link_color[::-1]) / 255.
+                ax.plot(xs_3d, ys_3d, zs_3d, color=_color)
+
+    # convert figure to numpy array
+    fig.tight_layout()
+    fig.canvas.draw()
+    img_w, img_h = fig.canvas.get_width_height()
+    img_vis = np.frombuffer(
+        fig.canvas.tostring_rgb(), dtype=np.uint8).reshape(img_h, img_w, -1)
+    img_vis = mmcv.rgb2bgr(img_vis)
+
+    plt.close(fig)
+
+    return img_vis
