@@ -71,7 +71,7 @@ class TopDown(BasePose):
 
     @property
     def with_neck(self):
-        """Check if has keypoint_head."""
+        """Check if has neck."""
         return hasattr(self, 'neck')
 
     @property
@@ -104,13 +104,13 @@ class TopDown(BasePose):
         the outer list indicating test time augmentations.
 
         Note:
-            batch_size: N
-            num_keypoints: K
-            num_img_channel: C (Default: 3)
-            img height: imgH
-            img width: imgW
-            heatmaps height: H
-            heatmaps weight: W
+            - batch_size: N
+            - num_keypoints: K
+            - num_img_channel: C (Default: 3)
+            - img height: imgH
+            - img width: imgW
+            - heatmaps height: H
+            - heatmaps weight: W
 
         Args:
             img (torch.Tensor[NxCximgHximgW]): Input images.
@@ -119,6 +119,7 @@ class TopDown(BasePose):
                 different joint types.
             img_metas (list(dict)): Information about data augmentation
                 By default this includes:
+
                 - "image_file: path to the image file
                 - "center": center of the bbox
                 - "scale": scale of the bbox
@@ -129,9 +130,9 @@ class TopDown(BasePose):
             return_heatmap (bool) : Option to return heatmap.
 
         Returns:
-            dict|tuple: if `return loss` is true, then return losses.
-              Otherwise, return predicted poses, boxes, image paths
-                  and heatmaps.
+            dict|tuple: if `return loss` is true, then return losses. \
+                Otherwise, return predicted poses, boxes, image paths \
+                and heatmaps.
         """
         if return_loss:
             return self.forward_train(img, target, target_weight, img_metas,
@@ -271,27 +272,28 @@ class TopDown(BasePose):
         img = img.copy()
 
         bbox_result = []
+        bbox_labels = []
         pose_result = []
         for res in result:
-            bbox_result.append(res['bbox'])
+            if 'bbox' in res:
+                bbox_result.append(res['bbox'])
+                bbox_labels.append(res.get('label', None))
             pose_result.append(res['keypoints'])
 
-        if len(bbox_result) > 0:
+        if bbox_result:
             bboxes = np.vstack(bbox_result)
-            labels = None
-            if 'label' in result[0]:
-                labels = [res['label'] for res in result]
             # draw bounding boxes
             imshow_bboxes(
                 img,
                 bboxes,
-                labels=labels,
+                labels=bbox_labels,
                 colors=bbox_color,
                 text_color=text_color,
                 thickness=bbox_thickness,
                 font_scale=font_scale,
                 show=False)
 
+        if pose_result:
             imshow_keypoints(img, pose_result, skeleton, kpt_score_thr,
                              pose_kpt_color, pose_link_color, radius,
                              thickness)
